

# BankPy Armazen de Dados Versatil
## Muito Simples De Usa

# Uma Grande Versão Esta Em Criação V - 1.0.8
# Teremos 2 Atualizações De Segurança Ate Chega Na Versão 1.0.8 Em Breve


## Armzene Os Dados Da Sua Aplicação de Uma Forma Muito Simples Você Pode Fazer a Comunincação Da Sua Aplicação Com A Outra Aplicação De Dados De Uma Forma Simples
# Exemplo:

```
import  Nome Do Modulo Ou Script

lembrando Que Você Deve Importa O Modulo/Script Criado Pela Sua Aplicação
```

**Você Pode Cria Um Armazen de Dados Para Sua Aplicaçã Como Sé Fosse Um Banco de Dados...**

**Esse Dados Serão Armazenado Em Um Arquivo Python Onde é Possivel Fazer a Comicação do Sua Aplicação Com Arquivo Python de Uma Forma Simples é Util**

* Não Reque Nada Especial 
* Utiliza Apena Modulo OS

```
from BankPy import *

Criando o Path
Create.Path.Pop('testando')
Esta Função Cria Uma Pasta Com um __init__.py
Este Dados Ficaram Salvo Nesse __init__.py

Conectando O Path Criado
var = Connect.Path.Pop('testando')

Armazenando Um Dado Na Variavel 
Write.Variable.Str.Pop(var'Nome_Da_Variavel''Conteudo da Variavel')

```

__Criado Por José Alexsandro__




[Desenvolvido Pela Star Comics](https://starcomicstar.weebly.com/)

[Portifolio_Do_Autor](https://alexsandrodev.netlify.app/)




